@@ -1,5 +1,6 @@
 //
-//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
+//  Copyright (c) 1994, 1995, 2015, 2016, 2018
+//  by Mike Romberg ( romberg@fsl.noaa.gov )
 //  Copyright (c) 1995, 1996, 1997-2002 by Brian Grayson (bgrayson@netbsd.org)
 //
 //  This file was written by Brian Grayson for the NetBSD and xosview
@@ -11,22 +12,22 @@
 //    authors for a copy.
 //
 
-#ifndef _MeterMaker_h
-#define _MeterMaker_h
+#ifndef MeterMaker_h
+#define MeterMaker_h
 
-#include "pllist.h"
-#include "meter.h"
-#include "xosview.h"
+#include "cmetermaker.h"
+
+class ResDB;
 
 
-class MeterMaker : public PLList<Meter *> {
+class MeterMaker : public ComMeterMaker {
 public:
-	MeterMaker(XOSView *xos);
-	void makeMeters(void);
+    mlist makeMeters(const ResDB &rdb);
 
 private:
-	XOSView *_xos;
+    void cpuFactory(const ResDB &rdb, mlist &meters) const;
+    void coreTempFactory(const ResDB &rdb, mlist &meters) const;
+    void sensorFactory(const ResDB &rdb, mlist &meters) const;
 };
 
-
 #endif
