@@ -1,5 +1,6 @@
 //
-//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
+//  Copyright (c) 1994, 1995, 2015, 2016, 2018
+//  by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  NetBSD port:
 //  Copyright (c) 1995, 1996, 1997-2002 by Brian Grayson (bgrayson@netbsd.org)
@@ -13,26 +14,25 @@
 //    authors for a copy.
 //
 
-#ifndef _PAGEMETER_H_
-#define _PAGEMETER_H_
+#ifndef pagemeter_h
+#define pagemeter_h
 
-#include "fieldmetergraph.h"
+#include "cpagemeter.h"
 
 
-class PageMeter : public FieldMeterGraph {
+class PageMeter : public ComPageMeter {
 public:
-	PageMeter( XOSView *parent, double total );
-	~PageMeter( void );
-
-	const char *name( void ) const { return "PageMeter"; }
-	void checkevent( void );
-	void checkResources( void );
+    PageMeter(void);
 
 protected:
-	void getpageinfo( void );
+    virtual std::pair<float, float> getPageRate(void) override;
 
 private:
-	u_int64_t previnfo_[2];
+    const size_t _psize;
+    std::vector<uint64_t> _previnfo;
+
+    // layout: { pages_in, pages_out }
+    void getPageStats(std::vector<uint64_t> &pageinfo) const;
 };
 
 
