@@ -1,5 +1,6 @@
 //
-//  Copyright (c) 1995, 1996, 1997-2002 by Brian Grayson (bgrayson@netbsd.org)
+//  Copyright (c) 1995, 1996, 1997-2002, 2015, 2016, 2018
+//  by Brian Grayson (bgrayson@netbsd.org)
 //
 //  This file was written by Brian Grayson for the NetBSD and xosview
 //    projects.
@@ -10,24 +11,22 @@
 //    authors for a copy.
 //
 
-#ifndef _SWAPMETER_H_
-#define _SWAPMETER_H_
+#ifndef swapmeter_h
+#define swapmeter_h
 
-#include "fieldmetergraph.h"
-#include "xosview.h"
+#include "cswapmeter.h"
 
 
-class SwapMeter : public FieldMeterGraph {
+
+class SwapMeter : public ComSwapMeter {
 public:
-	SwapMeter( XOSView *parent );
-	~SwapMeter( void );
-
-	const char *name( void ) const { return "SwapMeter"; }
-	void checkevent( void );
-	void checkResources( void );
+    SwapMeter(void);
 
 protected:
-	void getswapinfo( void );
+    virtual std::pair<uint64_t, uint64_t> getswapinfo(void) override;
+
+private:
+    void getSwapInfo(uint64_t &total, uint64_t &used) const;
 };
 
 
